<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-oc',
	'0_langue' => 'Nissart [oc_ni]',
	'0_liste' => 'spip-oc@rezo.net',
	'0_mainteneur' => 'Sébastien Donato : sebastien@donato.fr',

	// A
	'access_interface_graphique' => 'Tornar à l’interfaça grafica completa',
	'access_mode_texte' => 'Affichar l’interfaça textuala simplificada', # essai commentaire
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Modificar aquel article',
	'admin_modifier_auteur' => 'Modificar aquel autor',
	'admin_modifier_breve' => 'Modificar aquela brèva',
	'admin_modifier_mot' => 'Modificar aqueu mòt clau',
	'admin_modifier_rubrique' => 'Modificar aquela rubrica',
	'admin_recalculer' => 'Tornar calcular aquesta pàgina',
	'afficher_trad' => 'afichar li reviradas',
	'alerte_maj_impossible' => '<b>Alèrta!</b> Es impossible d’actualisar la basa SQL vèrs la version @version@; bessai li a un problema relatiu au drech de modificar la basa de donadas. Vorgatz contactar lo voastre aubergador.',
	'alerte_modif_info_concourante' => 'ATTENTION : Cette information a été modifié par ailleurs. La valeur actuelle est :', # MODIF
	'analyse_xml' => 'Analisa XML',
	'annuler' => 'Anular',
	'antispam_champ_vide' => 'Vorgatz laissar aquel camp vuèi:',
	'articles_recents' => 'Lu articles mai recents',
	'avis_archive_incorrect' => 'lo fichier arquiu es pas un fichier SPIP',
	'avis_archive_invalide' => 'lo fichier arquiu es pas valid',
	'avis_attention' => 'DAIDA !',
	'avis_champ_incorrect_type_objet' => 'Nom de camp incorrecte @name@ per object de tipe',
	'avis_colonne_inexistante' => 'La colòna @col@ existisse pas',
	'avis_erreur' => 'Error: veire çai sota',
	'avis_erreur_connexion' => 'Error de connexion',
	'avis_erreur_cookie' => 'problèma de cookie',
	'avis_erreur_fonction_contexte' => 'Error de programacion. Cau pas apelar aquela foncion dins aqueu contèxt.',
	'avis_erreur_mysql' => 'Error SQL ',
	'avis_erreur_sauvegarde' => 'Error dins la sauvagarda (@type@ @id_objet@) ! ',
	'avis_erreur_visiteur' => 'Problèma per accèdre à l’espaci privat',

	// B
	'barre_a_accent_grave' => 'Inserir una A accent grèu majuscula',
	'barre_aide' => 'Utilisar li escorchas tipografiqui per enriquir la voastra compaginacion',
	'barre_e_accent_aigu' => 'Inserir una E accent agut majuscula',
	'barre_eo' => 'Inserir una E dins l’O',
	'barre_eo_maj' => 'Inserir una E dins l’O majuscula',
	'barre_euro' => 'Inserir lo simbòl €',
	'barre_gras' => 'Metre en {{gras}}',
	'barre_guillemets' => 'Enrodar mé de « verguetas francesi »',
	'barre_guillemets_simples' => 'Enrodar mé de verguetas',
	'barre_intertitre' => 'Transformar en {{{intertitre}}}',
	'barre_italic' => 'Metre en {italics}',
	'barre_lien' => 'Transformar en [ligam ipertèxt->http://...]',
	'barre_lien_input' => 'Vorgatz indicar l’adreça dau voastre ligam (podètz indicar una adreça web sota la forma http://www.lomieusit.com ò simplament indicar lo número d’un article d’aqueu sit).',
	'barre_note' => 'Transformar en [[Nòta de bas de pàgina]]',
	'barre_quote' => '<quote>Citar un messatge</quote>',
	'bouton_changer' => 'Cambiar',
	'bouton_chercher' => 'Cercar',
	'bouton_choisir' => 'Chausir',
	'bouton_download' => 'Descargar',
	'bouton_enregistrer' => 'Registrar',
	'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la messatgeria interna',
	'bouton_radio_envoi_annonces' => 'Mandar lu anoncis editoriaus',
	'bouton_radio_non_envoi_annonces' => 'Mandar pas d’anoncis',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Mandar pas la tièra dei novetats',
	'bouton_recharger_page' => 'tornar cargar aquela pàgina',
	'bouton_telecharger' => 'Descargar',
	'bouton_upload' => 'Telecargar',
	'bouton_valider' => 'Validar',

	// C
	'cal_apresmidi' => 'après-miegjorn',
	'cal_jour_entier' => 'jorn entié',
	'cal_matin' => 'matin',
	'cal_par_jour' => 'calendier per jorn',
	'cal_par_mois' => 'calendier per mes',
	'cal_par_semaine' => 'calendier per setmana',
	'choix_couleur_interface' => 'color ',
	'choix_interface' => 'chausida de l’interfaça',
	'colonne' => 'Colomna',
	'confirm_changer_statut' => 'Atencion, avètz demandat de cambiar l’estatut d’aquel element. Desiratz continuar? ',
	'correcte' => 'corrècte',

	// D
	'date_aujourdhui' => 'encuèi',
	'date_avant_jc' => 'avans lo Crist',
	'date_dans' => 'dins @delai@',
	'date_de_mois_1' => '@j@ de genoier',
	'date_de_mois_10' => '@j@ d’octòbre',
	'date_de_mois_11' => '@j@ de novembre',
	'date_de_mois_12' => '@j@ de decembre',
	'date_de_mois_2' => '@j@ de febrier',
	'date_de_mois_3' => '@j@ de mars',
	'date_de_mois_4' => '@j@ d’abriu',
	'date_de_mois_5' => '@j@ de mai',
	'date_de_mois_6' => '@j@ de junh',
	'date_de_mois_7' => '@j@ de julhet',
	'date_de_mois_8' => '@j@ d’avost',
	'date_de_mois_9' => '@j@ de setembre',
	'date_demain' => 'deman',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour_heure' => '@jour@ à @heure@',
	'date_fmt_jour_mois' => 'lo @jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ dau @annee@',
	'date_fmt_mois_annee' => '@nommois@ dau @annee@',
	'date_fmt_nomjour_date' => 'lo @nomjour@ @date@',
	'date_heures' => 'oras',
	'date_hier' => 'ièr',
	'date_il_y_a' => 'fa @delai@',
	'date_jnum1' => '1er',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'diménegue',
	'date_jour_1_abbr' => 'dmg.',
	'date_jour_1_initiale' => 'dg.',
	'date_jour_2' => 'diluns',
	'date_jour_2_abbr' => 'dil.',
	'date_jour_2_initiale' => 'dl.',
	'date_jour_3' => 'dimars',
	'date_jour_3_abbr' => 'dmr.',
	'date_jour_3_initiale' => 'dm.',
	'date_jour_4' => 'dimècres',
	'date_jour_4_abbr' => 'dmc.',
	'date_jour_4_initiale' => 'dc.',
	'date_jour_5' => 'dijòus',
	'date_jour_5_abbr' => 'dij.',
	'date_jour_5_initiale' => 'dj.',
	'date_jour_6' => 'divendres',
	'date_jour_6_abbr' => 'div.',
	'date_jour_6_initiale' => 'dv.',
	'date_jour_7' => 'dissabta',
	'date_jour_7_abbr' => 'dis.',
	'date_jour_7_initiale' => 'ds.',
	'date_jours' => 'jorns',
	'date_minutes' => 'minutas',
	'date_mois' => 'mès',
	'date_mois_1' => 'genoier',
	'date_mois_10' => 'octòbre',
	'date_mois_11' => 'novembre',
	'date_mois_12' => 'decembre',
	'date_mois_2' => 'febrier',
	'date_mois_3' => 'mars',
	'date_mois_4' => 'abriu',
	'date_mois_5' => 'mai',
	'date_mois_6' => 'junh',
	'date_mois_7' => 'julhet',
	'date_mois_8' => 'avost',
	'date_mois_9' => 'setembre',
	'date_saison_1' => 'invèrn',
	'date_saison_2' => 'prima',
	'date_saison_3' => 'estiu',
	'date_saison_4' => 'auton',
	'date_secondes' => 'secondas',
	'date_semaines' => 'setmanas',
	'date_un_mois' => 'mes',
	'date_une_heure' => 'ora',
	'date_une_minute' => 'minuta',
	'date_une_seconde' => 'seconda',
	'date_une_semaine' => 'setmana',
	'dirs_commencer' => 'per començar vertadierament l’installacion',
	'dirs_preliminaire' => 'Preliminari : <b>Reglar lu drechs d’accès</b>',
	'dirs_probleme_droits' => 'Problèma de drechs d’accès',
	'dirs_repertoires_absents' => '<p><b>Lu repertòris seguents son pas estat trobats:</b></p><ul>@bad_dirs@.</ul>
  <p>Si pòu que vene d’un problema de majusculas ò minusculas mau mesi.
  Verificatz que li minusculas e majusculas d’aquelu repertòris correspoandon ben embé cen qu’es afichat
  çai sobre; s’es pas lo cas, tornatz nommar lu repertòris embé lo voastre logiciau FTP per corregir l’error.</p>
  <p>Un còup qu’auretz fach aquò, podretz ',
	'dirs_repertoires_suivants' => '<p><b>Lu repertòris seguents son pas accessibles en escritura :</b></p><ul>@bad_dirs@.</ul>
  <p>Per adobar aquò, utilisatz lo voastre client FTP per fin de reglar lu drechs d’accès de cadun
  d’aquelu repertòris. Lo guida d’installacion explica en detalh coma  procèdre.</p>
  <p>Un còup aquesta manipulacion facha, podretz ',
	'double_occurrence' => 'Dobla ocurrénça',

	// E
	'envoi_via_le_site' => 'Mandadís mé lo biais dau sit web',
	'erreur' => 'Error',
	'erreur_balise_non_fermee' => 'darrièra balisa non tapada :',
	'erreur_texte' => 'error(s)',

	// F
	'fichier_introuvable' => 'Fichier @fichier@ introuvable',
	'form_deja_inscrit' => 'Siètz ja inscrich(a).',
	'form_email_non_valide' => 'La voastra adreça e-mail es pas valida.',
	'form_forum_access_refuse' => 'Podètz plus accedir à-n-aqueu sit.',
	'form_forum_bonjour' => 'Boanjorn,',
	'form_forum_email_deja_enregistre' => 'Aquela adreça e-mail es ja registrada, podètz doncas utilisar lo voastre mòt de santa Clara costumier.',
	'form_forum_identifiant_mail' => 'Lo voastre novèl identificant ven de v’èstre mandat per e-mail.',
	'form_forum_identifiants' => 'Identificants personaus',
	'form_forum_indiquer_nom_email' => 'Indicatz aquí lo voastre nom e la voastra adreça e-mail. Lo voastre identificant personau arribarà rapidament, per corrier electronic.',
	'form_forum_login' => 'login :',
	'form_forum_message_auto' => '(aquò’s un messatge automatic)',
	'form_forum_pass' => 'mòt de santa Clara :',
	'form_forum_probleme_mail' => 'Problèma d’e-mail : si pòu pas mandar l’identificant.',
	'form_forum_voici1' => 'Vètz lu voastres identificants per poder participar à la vida
dau sit "@nom_site_spip@" (@adresse_site@) :',
	'form_forum_voici2' => 'Vètz lu voastres identificants per prepauar d’articles 
 sus lo sit "@nom_site_spip@" (@adresse_login@) :',
	'form_indiquer_email' => 'Vorgatz indicar la voastra adreça e-mail.',
	'form_indiquer_nom' => 'Vorgatz indicar lo voastre nom.',
	'form_indiquer_nom_site' => 'Vorgatz indicar lo nom dau voastre sit.',
	'form_pet_deja_enregistre' => 'Aqueu sit es ja registrat',
	'form_pet_signature_pasprise' => 'La voastra signatura es pas pilhada en còmpte.',
	'form_prop_confirmer_envoi' => 'Confirmar lo mandadís',
	'form_prop_description' => 'Descripcion/comentari',
	'form_prop_enregistre' => 'La voastra proposicion es registrada, apareisserà en linha après validacion per lu responsables dau sit.',
	'form_prop_envoyer' => 'Mandar un messatge',
	'form_prop_indiquer_email' => 'Vorgatz indicar una adreça e-mail valida',
	'form_prop_indiquer_nom_site' => 'Vorgatz indicar lo nom dau sit.',
	'form_prop_indiquer_sujet' => 'Vorgatz indicar un subjècte',
	'form_prop_message_envoye' => 'Messatge mandat',
	'form_prop_non_enregistre' => 'La voastra proposicion es pas estada registrada.',
	'form_prop_sujet' => 'Subjècte',
	'form_prop_url_site' => 'Adreça URL dau sit',
	'forum_non_inscrit' => 'Siètz pas inscrich(a), ò l’adreça ò lo mòt de santa Clara son erronèus.',
	'forum_par_auteur' => 'da @auteur@',
	'forum_titre_erreur' => 'Error...',

	// I
	'ical_texte_rss_articles' => 'Lo fichier "backend" dei articles d’aquèu sit si tròba à l’adreça :',
	'ical_texte_rss_articles2' => 'Podètz tambèn obténer de fichiers "backend" per lu articles de cada rubrica dau sit :',
	'ical_texte_rss_breves' => 'Existisse de mai un fichier contenent li brèvas dau sit. En precisar un nùmero de rubrica, obtendretz ren que li brèvas d’aquela rubrica.',
	'icone_a_suivre' => 'Da sègre',
	'icone_admin_site' => 'Administracion dau sit',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Ajuda',
	'icone_articles' => 'Articles',
	'icone_auteurs' => 'Autors',
	'icone_brouteur' => 'Navigacion rapida',
	'icone_configuration_site' => 'Configuracion',
	'icone_configurer_site' => 'Configurar lo voastre sit',
	'icone_creer_nouvel_auteur' => 'Crear un noveu autor',
	'icone_creer_rubrique' => 'Crear una rubrica',
	'icone_creer_sous_rubrique' => 'Crear una sosrubrica',
	'icone_deconnecter' => 'Si desconnectar',
	'icone_discussions' => 'Discussions',
	'icone_doc_rubrique' => 'Documents dei rubricas',
	'icone_ecrire_article' => 'Escriure un novèl article',
	'icone_edition_site' => 'Edicion',
	'icone_gestion_langues' => 'Gestion dei lengas',
	'icone_informations_personnelles' => 'Informacions personali',
	'icone_interface_complet' => 'interfaça completa',
	'icone_interface_simple' => 'Interfaça simplificada',
	'icone_maintenance_site' => 'Mantenença dau sit',
	'icone_messagerie_personnelle' => 'Messatgeria personala',
	'icone_repartition_debut' => 'Afichar la reparticion despí lo principi',
	'icone_rubriques' => 'Rubricas',
	'icone_sauver_site' => 'Sauvagarda dau sit',
	'icone_site_entier' => 'Tot lo sit',
	'icone_sites_references' => 'Sits referençats',
	'icone_statistiques' => 'Estadisticas dau sit',
	'icone_suivi_activite' => 'Seguir la vida dau sit',
	'icone_suivi_actualite' => 'Evolucion dau sit',
	'icone_suivi_pettions' => 'Seguir/gerar li peticions',
	'icone_suivi_revisions' => 'Modificacions dei articles',
	'icone_supprimer_document' => 'Suprimir aqueu document',
	'icone_supprimer_image' => 'Suprimir aquel imatge',
	'icone_tous_articles' => 'Toi lu voastres articles',
	'icone_tous_auteur' => 'Toi lu autors',
	'icone_visiter_site' => 'Veire lo site public',
	'icone_voir_en_ligne' => 'Veire en linha',
	'img_indisponible' => 'imatge indisponible',
	'impossible' => 'impossible',
	'info_a_suivre' => 'DA SEGRE &gt;&gt;',
	'info_acces_interdit' => 'Accès proïbit',
	'info_acces_refuse' => 'Accès refudat',
	'info_action' => 'Accion: @action@',
	'info_administrer_rubriques' => 'Podètz administrar aquela rubrica e li sosrubricas sieui',
	'info_adresse_non_indiquee' => 'Avètz pas indicat l’adreça de testar !',
	'info_aide' => 'AJUDA:',
	'info_ajouter_mot' => 'Ajustar aqueu mòt',
	'info_annonce' => 'ANONCI',
	'info_annonces_generales' => 'Anoncis generaus :',
	'info_article_propose' => 'Article prepauat',
	'info_article_publie' => 'Article publicat',
	'info_article_redaction' => 'Article en cors de redaccion',
	'info_article_refuse' => 'Article refudat',
	'info_article_supprime' => 'Article suprimit',
	'info_articles' => 'Articles',
	'info_articles_a_valider' => 'Lu articles de validar',
	'info_articles_proposes' => 'Articles prepauats',
	'info_articles_un' => '1 article',
	'info_auteurs_nombre' => 'autor(s)',
	'info_authentification_ftp' => 'autentificacion (per FTP).',
	'info_breves_2' => 'brèvas',
	'info_connexion_refusee' => 'Connexion refusada',
	'info_contact_developpeur' => 'Vorgatz contactar un desvolopaire.',
	'info_contenance' => 'Aqueu sit compren :',
	'info_contribution' => 'contribucions',
	'info_copyright' => 'es un logiciau liure distribuit @lien_gpl@.',
	'info_copyright_doc' => 'Per mai d’informacions, veire lo sit <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'sota licença GPL',
	'info_cours_edition' => 'Lu voastres articles en cors de redacion',
	'info_creer_repertoire' => 'Vorgatz crear un fichier ò un repertòri nomat',
	'info_creer_repertoire_2' => 'en dintre dau sosrepertòri <b>@repertoire@</b>, pi:',
	'info_creer_vignette' => 'creacion automatica de la vinheta',
	'info_deplier' => 'Desplegar',
	'info_descriptif_nombre' => 'descriptiu(s):',
	'info_description' => 'Descripcion:',
	'info_description_2' => 'Descripcion:',
	'info_dimension' => 'Dimensions:',
	'info_ecire_message_prive' => 'Escriure un messatge privat',
	'info_email_invalide' => 'Adreça e-mail invalida',
	'info_en_cours_validation' => 'Lu voastres articles en cors de redaccion',
	'info_en_ligne' => 'Aüra en linha:',
	'info_envoyer_message_prive' => 'Mandar un messatge privat à-n-aquel autor',
	'info_erreur_requete' => 'Error dins la requesta',
	'info_erreur_squelette2' => 'Minga d’esqueleta <b>@fichier@</b> es disponibla...',
	'info_erreur_systeme' => 'Error sistèma (errno @errsys@)',
	'info_erreur_systeme2' => 'Bessai lo disc dur es plen, ò la basa de donadas degalhada.<br />
<span style="color:red;">Provatz de <a href=\'@script@\'>reparar la basa</a>, ò contactatz lo voastre aubergador.</span>',
	'info_fini' => 'Es acabat !',
	'info_format_image' => 'Formats d’imatges que poadon èstre utilisats per crear de vinhetas: @gd_formats@.',
	'info_format_non_defini' => 'format non definit',
	'info_grand_ecran' => 'Grand ecran',
	'info_image_aide' => 'AJUDA',
	'info_image_process_titre' => 'Metòde de fabricacion dei vinhetas',
	'info_impossible_lire_page' => '<b>Error !</b> Impossible de lièger la pàgina <tt><html>@test_proxy@</html></tt> à travèrs lo proxy <tt>',
	'info_installation_systeme_publication' => 'Installacion dau sistema de publicacion...',
	'info_installer_documents' => 'Podètz installar automaticament toi lu documents contenguts dins lo dorsier @upload@.',
	'info_installer_ftp' => 'Coma administrator, podètz installar (per FTP) de fichiers dins lo dorsier @upload@ pi lu seleccionar directament aquí.',
	'info_installer_images' => 'Podètz installar d’imatges ai formats JPEG, GIF e PNG.',
	'info_installer_images_dossier' => 'Installar d’imatges dins lo dorsier @upload@ per lu poder seleccionar aquí.',
	'info_interface_complete' => 'interfaça completa',
	'info_interface_simple' => 'Interfaça simplificada',
	'info_joindre_document_article' => 'Podètz jónher à-n-aquel article de documents de tipe',
	'info_joindre_document_rubrique' => 'Podètz jónher à-n-aquela rubrica de documents de tipe',
	'info_joindre_documents_article' => 'Podètz jónher à-n-aquel article de documents de tipe :',
	'info_l_article' => 'l’article',
	'info_la_breve' => 'la brèva',
	'info_la_rubrique' => 'la rubrica',
	'info_langue_principale' => 'Lenga principala dau sit',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => 'per @les_auteurs@ ',
	'info_logo_format_interdit' => 'Solets lu lògos de formats @formats@ son  autorisats.',
	'info_logo_max_poids' => 'Lu lògos devon obligatòriament faire mens de @maxi@ (aquèu fichier fa @actuel@).',
	'info_mail_fournisseur' => 'vos@provesidor.org',
	'info_message_2' => 'MESSATGE',
	'info_message_supprime' => 'MESSATGE SUPRIMIT',
	'info_mise_en_ligne' => 'Data de mesa en linha:',
	'info_modification_parametres_securite' => 'modificacions dei paramètres de seguretat',
	'info_mois_courant' => 'En cors de mes:',
	'info_mot_cle_ajoute' => 'Lo mòt clau seguent es estat ajustat à ',
	'info_multi_herit' => 'Lenga predefinida',
	'info_multi_langues_soulignees' => 'Li <u>lengas solinhadas</u> benefícion d’una revirada de toi lu tèxtes de l’interfaça. Se seleccionatz aqueli lengas, totplen d’elements dau sit public (datas, formularis) se reviraràn automaticament. Per li lengas non solinhadas, aquelu elements apareisseràn dins la lenga principala dau sit.', # MODIF
	'info_multilinguisme' => 'Multilengüisme',
	'info_nom_non_utilisateurs_connectes' => 'Lo voastre nom apareisse pas dins la tièra dei utilisaires connectats.',
	'info_nom_utilisateurs_connectes' => 'Lo voastre nom apareisse dins la tièra dei utilisaires connectats.',
	'info_nombre_en_ligne' => 'Aüra en linha :',
	'info_non_resultat' => 'Minga de resultat per \\\\\\"@cherche_mot@\\\\\\"',
	'info_non_utilisation_messagerie' => 'Utilisetz pas la messatgeria interna d’aqueu sit.',
	'info_nouveau_message' => 'AVÈTZ UN MESSATGE NOVÈU',
	'info_nouveaux_messages' => 'AVÈTZ @total_messages@ MESSATGES NÒUS',
	'info_numero_abbreviation' => 'N° ',
	'info_pense_bete' => 'NÒTA DE RENEMBRANÇA ',
	'info_petit_ecran' => 'Pichon ecran',
	'info_pixels' => 'pixèus',
	'info_plusieurs_mots_trouves' => 'Mantun mòts claus trobats per "@cherche_mot@":',
	'info_portfolio_automatique' => 'Poartfòlio automatic:',
	'info_premier_resultat' => '[@debut_limit@ promiers resultats de @total@]',
	'info_premier_resultat_sur' => ' [@debut_limit@ promiers resultats de @total@]',
	'info_propose_1' => '[@nom_site_spip@] Prepaua: @titre@',
	'info_propose_2' => 'Article prepauat
----------------',
	'info_propose_3' => 'L’article "@titre@" es prepauat à la publicacion.',
	'info_propose_4' => 'Siètz convidat à lo venir consultar e à donar la voastra opinion',
	'info_propose_5' => 'dins lo fòro que li es estacat. Es disponibla à l’adreça:',
	'info_publie_01' => 'L’article "@titre@" es estat validat per @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICA: @titre@',
	'info_publie_2' => 'Article publicat
----------------',
	'info_rechercher' => 'Recercar',
	'info_rechercher_02' => 'Recercar:',
	'info_remplacer_vignette' => 'Remplaçar la vinheta predefinida per un lògo personalisat :',
	'info_sans_titre_2' => 'sensa titre',
	'info_selectionner_fichier' => 'Podètz seleccionar un fichier dau dorsier @upload@',
	'info_selectionner_fichier_2' => 'Seleccionar un fichier :',
	'info_supprimer_vignette' => 'suprimir la vinheta',
	'info_symbole_bleu' => 'Lo simbòl <b>blu</b> marca una <b>nòta de remembrança</b>: es à dire un messatge dau voastre usatge personau.',
	'info_symbole_jaune' => 'Lo simbòl <b>jaune</b> marca un <b>anonci per toi lu redactors </b>: lu administrators la poadon modificar, cada redactor la pòu veire.',
	'info_symbole_vert' => 'Lo simbòl <b>verd</b> marca lu <b>messatges escambiats mé d’autres utilisaires</b> dau sit.',
	'info_telecharger_nouveau_logo' => 'Telecargar un novèu lògo :',
	'info_telecharger_ordinateur' => 'Telecargar despí lo voastre ordinator :',
	'info_tous_resultats_enregistres' => '[toi lu resultats son registrats]',
	'info_tout_afficher' => 'Far paréisser tot',
	'info_travaux_texte' => 'Aqueu sit es pas encara configurat. Tornatz plus tard...',
	'info_travaux_titre' => 'Sit en òbras',
	'info_trop_resultat' => 'Tròp de resultats per \\\\\\&quot;@cherche_mot@\\\\\\&quot;; vorgatz afinar la recerca.',
	'info_utilisation_messagerie_interne' => 'Utilisatz la messatgeria interna d’aqueu sit.',
	'info_valider_lien' => 'validar aquel estac',
	'info_verifier_image' => ', vorgatz verificar que lu voastres imatges son estats transferits correctament.',
	'info_vignette_defaut' => 'Vinheta predefinida',
	'info_vignette_personnalisee' => 'Vinheta personalisada',
	'info_visite' => 'visita:',
	'info_vos_rendez_vous' => 'Lu voastres rendètz-vos à venir',
	'infos_vos_pense_bete' => 'Li voastri nòtas de renembrança ',

	// L
	'lien_afficher_icones_seuls' => 'Far paréisser li icònas unicament',
	'lien_afficher_texte_icones' => 'Far paréisser li icònas e lo tèxt',
	'lien_afficher_texte_seul' => 'Far paréisser lo tèxt solet',
	'lien_liberer' => 'liberar',
	'lien_liberer_tous' => 'Liberar tot',
	'lien_nouvea_pense_bete' => 'NOVÈLA NÒTA DE RENEMBRANÇA ',
	'lien_nouveau_message' => 'MESSATGE NOVÈU',
	'lien_nouvelle_annonce' => 'ANONCI NOVÈU',
	'lien_petitions' => 'PETICION',
	'lien_popularite' => 'popularitat: @popularite@%',
	'lien_racine_site' => 'RAIÇ DAU SIT',
	'lien_reessayer' => 'tornar temptar',
	'lien_repondre_message' => 'Respoandre à-n-aqueu messatge',
	'lien_supprimer' => 'suprimir',
	'lien_tout_afficher' => 'Far tot paréisser',
	'lien_visite_site' => 'visitar aqueu sit',
	'lien_visites' => '@visites@ visitas',
	'lien_voir_auteur' => 'Veire aquel autor',
	'ligne' => 'Linha',
	'login' => 'Connexion',
	'login_acces_prive' => 'accès à l’espaci privat',
	'login_autre_identifiant' => 'si connectar emb’un autre identificant',
	'login_cookie_accepte' => 'Vorgatz configurar lo voastre navigador per que lu accèpte (aumens per aqueu sit).',
	'login_cookie_oblige' => 'Per vos identificar d’una maniera segura sus aquest sit, vos cau acceptar lu cookies.',
	'login_deconnexion_ok' => 'Siètz desconnectat/ada.',
	'login_erreur_pass' => 'Error de mòt de santa Clara.',
	'login_espace_prive' => 'espaci privat',
	'login_identifiant_inconnu' => 'L’identificant « @login@ » es desconoissut.',
	'login_login' => 'Login :',
	'login_login2' => 'Login ò adreça email:',
	'login_login_pass_incorrect' => '(Login ò mòt de santa Clara incorret.)',
	'login_motpasseoublie' => 'mòt de Santa Clara oblidat ?',
	'login_non_securise' => 'Mèfi, qu’aqueu formulari es pas securisat.
   Se volètz pas que lo voastre mòt de santa Clara sigue
   interceptat sus la ret, vorgatz activar Javascript 
   dins lo voastre navigador e',
	'login_nouvelle_tentative' => 'novèla temptativa',
	'login_par_ici' => 'Siètz registrat... per aquí...',
	'login_pass2' => 'Mòt de santa Clara :',
	'login_preferez_refuser' => '<b>Se preferissètz refudar lu cookies</b>, un autre metòde de connexion (mens securisat) es à la voastra disposicion:',
	'login_recharger' => 'Tornar cargar aquela pàgina',
	'login_rester_identifie' => 'Demorar identificat quaucu jorns',
	'login_retour_public' => 'Tornar au sit public',
	'login_retour_site' => 'Tornar au sit public',
	'login_retoursitepublic' => 'tornar au sit public',
	'login_sinscrire' => 's’inscriure',
	'login_test_navigateur' => 'test navigador/tornar connectar',
	'login_verifiez_navigateur' => '(verificatz pura que lo voastre navigador a pas conservat lo mòt de santa Clara en memòria...)',

	// M
	'masquer_trad' => 'Escondre li reviradas',
	'module_fichiers_langues' => 'Fichiers de langa',

	// N
	'navigateur_pas_redirige' => 'Se lo voastre navigador es pas redirigit, clicatz aquí per continuar.',
	'numero' => 'Numerò',

	// O
	'occurence' => 'Ocurrénça',
	'onglet_affacer_base' => 'Escafar la basa',
	'onglet_auteur' => 'L’autor',
	'onglet_contenu_site' => 'Contengut dau sit',
	'onglet_evolution_visite_mod' => 'Evolucion',
	'onglet_fonctions_avances' => 'Foncions avançadas',
	'onglet_informations_personnelles' => 'Informacions personali',
	'onglet_interactivite' => 'Interactivitat',
	'onglet_messagerie' => 'Messatgeria',
	'onglet_repartition_rubrique' => 'Reparticion per rubricas',
	'onglet_save_restaur_base' => 'Sauvagardar/restaurar la basa',
	'onglet_vider_cache' => 'Vuar l’amagador',

	// P
	'pass_choix_pass' => 'Vorgatz chausir lo voastre novèu mòt de santa Clara :',
	'pass_erreur' => 'Error',
	'pass_erreur_acces_refuse' => '<b>Error :</b> podètz plus accedir à-n-aqueu sit.',
	'pass_erreur_code_inconnu' => '<b>Error :</b> aqueu còde correspoande à minga de visitaires qu’an accès à-n-aqueu sit.',
	'pass_erreur_non_enregistre' => '<b>Error :</b> l’adreça <tt>@email_oubli@</tt> es pas registrada sus aqueu sit.',
	'pass_erreur_non_valide' => '<b>Error :</b> aquel e-mail <tt>@email_oubli@</tt> es pas valid !',
	'pass_erreur_probleme_technique' => '<b>Error:</b> per l’encausa d’un problema tecnic, l’e-mail si pòu pas mandar. ',
	'pass_espace_prive_bla' => 'L’espaci privat d’aquest sit es dubèrt ai
  visitaires que si son inscrichs. Un còup registrat/ada,
  podrètz consultar lu articles en cors de redaccion,
  prepauar d’articles novèus e participar à toi lu fòros.',
	'pass_forum_bla' => 'Avètz demandat d’intervenir dins un fòro
  reservat ai visitaires registrats.',
	'pass_indiquez_cidessous' => 'Marcatz çai sota l’adreça e-mail dont
 vos registreretz lo còup passat.
   Receberetz un e-mail que vos balharà lo biais de
    tornar trobar lo voastre accès.',
	'pass_mail_passcookie' => '(aquò es un messatge automatic)
Per tornar trobar lo voastre accès au sit
@nom_site_spip@ (@adresse_site@)

Vorgatz anar à l’adreça seguenta:

    @sendcookie@

Podretz intrar un mòt de santa Clara novèu
e vos tornar connectar au sit.

',
	'pass_mot_oublie' => 'Mòt de santa Clara oblidat',
	'pass_nouveau_enregistre' => 'Lo voastre novèu mòt de santa Clara es estat registrat.',
	'pass_nouveau_pass' => 'Mòt de santa Clara novèu',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Denembrança dau mòt de santa Clara',
	'pass_quitter_fenetre' => 'Quitar aquesta fenèstra ',
	'pass_rappel_login' => 'Renembrança: lo voastre identificant (login) es « @login@ ».',
	'pass_recevoir_mail' => 'Receberetz un e-mail que vos explicarà coma tornar trobar lo voastre accès au sit.',
	'pass_retour_public' => 'Tornar au sit public',
	'pass_rien_a_faire_ici' => 'Ren à faire aquí.',
	'pass_vousinscrire' => 'S’inscriure sus aquest sit',
	'precedent' => 'precedent',
	'previsualisation' => 'Previsualisacion',
	'previsualiser' => 'Previsualisar',

	// R
	'retour' => 'Tornar',

	// S
	'spip_conforme_dtd' => 'SPIP considèra aqueu document coma confòrm au sieu DOCTYPE :',
	'squelette' => 'esqueleta',
	'squelette_inclus_ligne' => 'esqueleta inclusa, linha',
	'squelette_ligne' => 'esqueleta, linha',
	'stats_visites_et_popularite' => '@visites@ visitas ; popularitat : @popularite@',
	'suivant' => 'seguent',

	// T
	'taille_ko' => '@taille@ Ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ octets',
	'texte_actualite_site_1' => 'Quora seretz familharisat/ada mé l’interfaça, podretz clicar sus «',
	'texte_actualite_site_2' => 'interfaça completa',
	'texte_actualite_site_3' => '» per aver mai de possibilitats.',
	'texte_creation_automatique_vignette' => 'La creacion automatica de vinhetas de previsualisacion es activada sus aqueu sit. S’installatz à partir d’aqueu formulari d’imatges au(ai) format(s) @gd_formats@, seràn acompanhats d’una vinheta d’una talha maximala de @taille_preview@ pixèls.',
	'texte_documents_associes' => 'Lu documents seguents son associats à l’article, ma son pas estats drech inserits. Segon la compaginacion dau sit public, podràn aparéisser sota forma de documents jonchs.',
	'texte_erreur_mise_niveau_base' => 'Error de basa de donadas pendent la mesa à nivèu. L’imatge <b>@fichier@</b> es pas passat (article @id_article@).
  Notatz ben aquela referença, tornatz ensajar la mesa à nivèu, e verificatz pi que lu imatges aparéisson encara dins lu articles.',
	'texte_erreur_visiteur' => 'Avètz provat d’accèdre à l’espaci privat m’un identificant que lo permete pas.',
	'texte_inc_auth_1' => 'Siètz identificat/ada coma
   <b>@auth_login@</b>, ma aqueu login existisse pas ò pas plus mai dins la basa.
  Temptatz de vos',
	'texte_inc_auth_2' => 'tornar connectar',
	'texte_inc_auth_3' => ', après aver eventualament quitat pi
  tornat lançar lo voastre navigador.',
	'texte_inc_config' => 'Li modificacions fachi dins aquesti pàginas influençan bravament lo
 foncionament dau voastre sit. Vos aconselham de pas i intervenir tant que siètz pas
 acostumat/ada au foncionament dau sistema SPIP. <br /><br /><b>
 En generau, si conselha foart
 de laissar la carga d’aquesti pàginas au webmèstre principau dau voastre sit.</b>',
	'texte_inc_meta_1' => 'Lo sistèma a rescontrat un error dins l’escritura dau fichier <code>@fichier@</code>. Vorgatz, coma administrator/triz dau sit,',
	'texte_inc_meta_2' => 'verificar lu drechs d’escritura',
	'texte_inc_meta_3' => 'sus lo repertòri <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'en cors de redaccion',
	'texte_statut_poubelle' => 'au bordilhier',
	'texte_statut_propose_evaluation' => 'prepauat per evaluacion',
	'texte_statut_publie' => 'publicat en linha',
	'texte_statut_refuse' => 'refudat',
	'titre_ajouter_mot_cle' => 'AJUSTAR UN MÒT CLAU :',
	'titre_cadre_raccourcis' => 'ESCORCHAS :',
	'titre_changer_couleur_interface' => 'Cambiar la color de l’interfaça',
	'titre_image_admin_article' => 'Podetz administrar aquel article',
	'titre_image_administrateur' => 'Administrator',
	'titre_image_aide' => 'D’ajuda sus aquel element',
	'titre_image_auteur_supprime' => 'Autor suprimit',
	'titre_image_redacteur' => 'Redactor sensa accès',
	'titre_image_redacteur_02' => 'Redactor',
	'titre_image_visiteur' => 'Visitaire',
	'titre_joindre_document' => 'JÓNHER UN DOCUMENT',
	'titre_mots_cles' => 'MÒTS CLAUS',
	'titre_probleme_technique' => 'Atencion : un problema tecnic (servidor SQL) empacha d’accedir à-n-aquela part dau sit. Mercé de la voastra indulgença.',
	'titre_publier_document' => 'PUBLICAR UN DOCUMENT DINS AQUELA RUBRICA',
	'titre_statistiques' => 'Estatisticas dau sit',
	'titre_titre_document' => 'Titre dau document :',
	'todo' => 'De venir',
	'trad_reference' => '(referença dei reviradas)',

	// Z
	'zbug_balise_b_aval' => ' : balisa B en aval',
	'zbug_balise_inexistante' => 'Balisa @balise@ mau declarada per @from@ ',
	'zbug_boucle' => 'bloca',
	'zbug_boucle_recursive_undef' => 'bloca recursiva non definida',
	'zbug_champ_hors_boucle' => 'Camp @champ@ fòra bloca',
	'zbug_champ_hors_motif' => 'Camp @champ@ en defòra d’una bloca de motiu @motif@',
	'zbug_code' => 'còde',
	'zbug_critere_inconnu' => 'critèri esconoissut @critere@',
	'zbug_distant_interdit' => 'extèrne proïbit',
	'zbug_doublon_table_sans_cle_primaire' => 'doblons sus una taula sensa clau primari atomica',
	'zbug_doublon_table_sans_index' => 'doblons sus una taula sensa indèx',
	'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla',
	'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barrador manca',
	'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorrècta',
	'zbug_erreur_compilation' => 'Error de compilacion',
	'zbug_erreur_execution_page' => 'error d’execucion de la pàgina',
	'zbug_erreur_filtre' => 'Error: filtre <b>« @filtre@ »</b> non definit',
	'zbug_erreur_meme_parent' => '{meme_parent} s’aplica unicament ai blocas (FORUMS) ò (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Error(s) dins l’esqueleta',
	'zbug_info_erreur_squelette' => 'Error sobre lo sit',
	'zbug_inversion_ordre_inexistant' => 'inversion d’un òrdre inexistent',
	'zbug_pagination_sans_critere' => 'Balisa #PAGINATION sensa critèri {pagination} ò emplegada dins una bocla recursiva',
	'zbug_parametres_inclus_incorrects' => 'Paramètres d’inclusion incorrèctes',
	'zbug_profile' => 'Temps de calcul : @time@',
	'zbug_resultat' => 'resultat',
	'zbug_serveur_indefini' => 'servidor SQL endefinit',
	'zbug_table_inconnue' => 'Taula SQL « @table@ » esconoissuda',
	'zxml_connus_attributs' => 'atributs conoissuts',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'atribut pas conoissut',
	'zxml_inconnu_balise' => 'balisa pas conoissuda',
	'zxml_inconnu_entite' => 'entitat pas conoissuda',
	'zxml_inconnu_id' => 'ID pas conoissut',
	'zxml_mais_de' => 'ma de',
	'zxml_non_conforme' => 'es pas confòrm au motiu',
	'zxml_non_fils' => 'es pas un enfant de',
	'zxml_nonvide_balise' => 'balisa non vuèia',
	'zxml_obligatoire_attribut' => 'atribut obligatòri ma absent dins',
	'zxml_succession_fils_incorrecte' => 'succession dei enfants incorrècte',
	'zxml_survoler' => 'susvolar per veire lu corrèctes',
	'zxml_valeur_attribut' => 'valor de l’atribut',
	'zxml_vide_balise' => 'balise vuèia',
	'zxml_vu' => 'vist adés'
);

?>
